@@ -2,8 +2,9 @@
 import logging
 from importlib.metadata import version
 
-logging.basicConfig(format='%(asctime)s | %(levelname)s | %(message)s', 
-                    datefmt='%y-%m-%d %H:%M')
+logging.basicConfig(
+    format="%(asctime)s | %(levelname)s | %(message)s",
+    datefmt="%y-%m-%d %H:%M",
+)
 
 __version__ = version("instrumentum")
-
