@@ -1,19 +1,14 @@
 # Individual functions to plot advanced analysis
-import pandas as pd
-import numpy as np
+import logging
+
+import matplotlib.patheffects as pe
 import matplotlib.pyplot as plt
 import seaborn as sns
-import matplotlib.patheffects as pe
-import logging
-import matplotlib.ticker as mtick
-
-
-from matplotlib.patches import Patch
 from matplotlib.lines import Line2D
 
 from instrumentum.analysis.plots import (
-    plot_continuos_bin_with_binary_target,
     plot_categorical_with_binary_target,
+    plot_continuos_bin_with_binary_target,
 )
 
 
@@ -42,7 +37,9 @@ def dashboard_continuos_with_binary_target(
 
     ncols = 3
     nrows = 3
-    fig, axs = plt.subplots(ncols=ncols, nrows=nrows, figsize=(6 * ncols, 5 * nrows))
+    fig, axs = plt.subplots(
+        ncols=ncols, nrows=nrows, figsize=(6 * ncols, 5 * nrows)
+    )
 
     # sns.barplot(
     #     data=df,
@@ -107,7 +104,10 @@ def dashboard_continuos_with_binary_target(
             common_norm=False,
             palette=palette,
             # legend=False,
-            path_effects=[pe.Stroke(linewidth=2, foreground="black"), pe.Normal()],
+            path_effects=[
+                pe.Stroke(linewidth=2, foreground="black"),
+                pe.Normal(),
+            ],
         )
 
         extra_legend_elements += [
@@ -124,7 +124,9 @@ def dashboard_continuos_with_binary_target(
 
     if handles:
         for h, t in zip(handles, ax_large.legend_.texts):
-            h.set_label(t.get_text())  # assign the legend labels to the handles
+            h.set_label(
+                t.get_text()
+            )  # assign the legend labels to the handles
 
     ax_large.legend(handles=handles + extra_legend_elements, loc="upper right")
     ax_large.set_title("Distribution by target")
@@ -157,9 +159,13 @@ def dashboard_continuos_with_binary_target(
 
     if handles:
         for h, t in zip(handles, axs[1, 2].legend_.texts):
-            h.set_label(t.get_text())  # assign the legend labels to the handles
+            h.set_label(
+                t.get_text()
+            )  # assign the legend labels to the handles
 
-    axs[1, 2].legend(handles=handles + extra_legend_elements, loc="lower right")
+    axs[1, 2].legend(
+        handles=handles + extra_legend_elements, loc="lower right"
+    )
     axs[1, 2].set_title("Cumulative Distribution")
 
     ##
@@ -219,7 +225,9 @@ def dashboard_categorical_with_binary_target(
 
     ncols = 3
     nrows = 2
-    fig, axs = plt.subplots(ncols=ncols, nrows=nrows, figsize=(6 * ncols, 5 * nrows))
+    fig, axs = plt.subplots(
+        ncols=ncols, nrows=nrows, figsize=(6 * ncols, 5 * nrows)
+    )
 
     ax_large = plt.subplot2grid((nrows, ncols), (1, 0), colspan=3)
 
@@ -262,7 +270,9 @@ def dashboard_categorical_with_binary_target(
 
     if handles:
         for h, t in zip(handles, ax.legend_.texts):
-            h.set_label(t.get_text())  # assign the legend labels to the handles
+            h.set_label(
+                t.get_text()
+            )  # assign the legend labels to the handles
 
     ax.legend(handles=handles + extra_legend_elements, loc="lower right")
     ax.set_title("Cumulative Distribution")
@@ -287,7 +297,9 @@ def dashboard_categorical_with_binary_target(
         ax=ax_large,
         cluster=cluster,
         palette=palette,
-        sort_func=lambda grp: grp.sort_values(["all"], ascending=False, inplace=True),
+        sort_func=lambda grp: grp.sort_values(
+            ["all"], ascending=False, inplace=True
+        ),
     )
 
     # fig.tight_layout()
